@@ -1,6 +1,8 @@
 import asyncio
 import logging
 
+from auth.Authenticator import Authenticator
+
 from data.payload.DataPayloadProcessor import DataPayloadProcessor
 from data.websocket.DataWebSocket import DataWebSocket
 
@@ -9,12 +11,22 @@ from data.websocket.DataWebSocket import DataWebSocket
 # todo: need to handle re-connects
 class WebSocketRunner:
 
-    def __init__(self, url, payload_processor: DataPayloadProcessor, ping_interval=20):
+    def __init__(self, url, payload_processor: DataPayloadProcessor, ping_interval=20, authenticator: Authenticator = None):
         logging.info(f'Websocket runner initialized with URL:{url}')
+        self.url = url
+        self.authenticator = self.init_authenticator(authenticator)
         self.payload_processor = payload_processor
         self.web_socket = DataWebSocket(url, ping_interval)
         self.loop = asyncio.get_event_loop()
 
+    def init_authenticator(self, authenticator: Authenticator):
+        if authenticator is None:
+            return None
+        authenticator.authenticate()
+        if authenticator.should_update_url():
+            self.url = authenticator.update_url(self.url)
+        return authenticator
+
     def fetch_single_payload(self):
         return self.loop.run_until_complete(self.__receive_single_payload())
 
